<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Silenciar/restaurar volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Controlo de volume: os seguintes atalhos não foram registados: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>(muted)</source>
        <translation>(sem som)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Definições do Controlo de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo a controlar</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Silenciar com a roda do rato</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permitir volume acima de 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Always notify about volume changes</source>
        <translation>Notificar sempre sobre a alteração de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Notificar sobre as alterações de volume com o teclado</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Nível de ajuste do volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Gestor de som externo</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="59"/>
        <source>Launch mixer</source>
        <translation>Iniciar gestor de som</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="60"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Gestor de som</translation>
    </message>
</context>
</TS>
